from .PRSAW import *

__title__ = "prsaw"
__summary__ = (
    "PRSAW, an acronym for `Python Random Stuff API Wrapper`, is a wrapper for the Random Stuff API."
)
__uri__ = "https://github.com/CodeWithSwastik/prsaw"
__version__ = "0.2.0"
__author__ = "Swas.py"
__email__ = "cwswas.py@gmail.com"
__license__ = "MIT License"
__copyright__ = "Copyright 2021 {}".format(__author__)

def get_version():
    return __version__
